2D signed coordinate in screen space

This struct is what you should use when positioning graphics elements as it can handle negative coordinates. To output pixel coordinates, use UnsignedCoord.

Structs

2D coordinate type

Traits

Convert a value to an unsigned coordinate