[][src]Struct embedded_graphics::pixelcolor::Gray2

pub struct Gray2(_);

2 bit grayscale color.

Methods

impl Gray2[src]

pub const fn new(luma: u8) -> Self[src]

Creates a new grayscale color.

Too large luma values are masked to the valid range by setting the upper bits to 0.