ContainsPoint

Trait ContainsPoint 

pub trait ContainsPoint {
    // Required method
    fn contains(&self, point: Point) -> bool;
}
Trait to check if a point is inside a closed shape.

Required Methods

fn contains(&self, point: Point) -> bool

Returns true if the given point is inside the shape.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors