pub struct Style<P: PixelColor> {
    pub fill_color: Option<P>,
    pub stroke_color: Option<P>,
    pub stroke_width: u8,
}
Style properties for an object

Fields

fill_color: Option<P>

Fill colour of the object

For fonts, this is the background colour of the text

stroke_color: Option<P>

Stroke (border/line) color of the object

For fonts, this is the foreground colour of the text

stroke_width: u8

Stroke width

Set the stroke width for an object. Has no effect on fonts.

Implementations

Create a new style with a given stroke value and defaults for everything else