[][src]Trait embedded_graphics::geometry::Dimensions

pub trait Dimensions {
    fn top_left(&self) -> Point;
fn bottom_right(&self) -> Point;
fn size(&self) -> Size; }

Adds the ability to get the dimensions/position of a graphics object

This should be implemented for all builtin embedded-graphics primitives and fonts. Third party implementations do not have to implement this trait as an object may not have a known size. If the object does have a known size, this trait should be implemented.

Required methods

fn top_left(&self) -> Point

Get the top left corner of the bounding box for an object

fn bottom_right(&self) -> Point

Get the bottom right corner of the bounding box for an object

fn size(&self) -> Size

Get the width and height for an object

Loading content...

Implementors

impl<'a, C> Dimensions for ImageBmp<'a, C> where
    C: PixelColor + From<<C as PixelColor>::Raw>, 
[src]

impl<'a, C> Dimensions for ImageTga<'a, C> where
    C: PixelColor + From<<C as PixelColor>::Raw>, 
[src]

impl<'a, C, BO> Dimensions for Image<'a, C, BO> where
    C: PixelColor + From<<C as PixelColor>::Raw>,
    BO: ByteOrder
[src]

impl<'a, C, Conf> Dimensions for FontBuilder<'a, C, Conf> where
    C: PixelColor,
    Conf: FontBuilderConf
[src]

fn size(&self) -> Size[src]

Get the bounding box of a piece of text

Currently does not handle newlines (but neither does the rasteriser). It will give (0, 0) if the string to render is empty.

impl<C> Dimensions for Circle<C> where
    C: PixelColor
[src]

impl<C> Dimensions for Line<C> where
    C: PixelColor
[src]

impl<C> Dimensions for Rectangle<C> where
    C: PixelColor
[src]

impl<C> Dimensions for Triangle<C> where
    C: PixelColor
[src]

Loading content...