Enum embedded_graphics::pixelcolor::BinaryColor [−][src]
pub enum BinaryColor {
Off,
On,
}Expand description
Binary color.
BinaryColor is used for displays and images with two possible color states.
The interpretation of active and inactive states can be different for
different types of displays. A BinaryColor::On might represent a black
pixel on an LCD and a white pixel on an OLED display.
To simplify the conversion from BinaryColor to RGB and grayscale color
types the default conversions assume that BinaryColor::Off is black and
BinaryColor::On is white.
Conversion between BinaryColor and bool
use embedded_graphics::pixelcolor::BinaryColor; // A BinaryColor can be converted to a bool by using the is_on and is_off methods. let color = BinaryColor::On; assert!(color.is_on()); assert!(color.invert().is_off()); // BinaryColor implements From<bool>. let bool_value = true; let color: BinaryColor = bool_value.into(); assert_eq!(color, BinaryColor::On); // this is equivalent to: let bool_value = true; let color = if bool_value { BinaryColor::On } else { BinaryColor::Off }; assert_eq!(color, BinaryColor::On);
Variants
Inactive pixel.
Active pixel.
Implementations
Inverts the color.
Examples
use embedded_graphics::pixelcolor::BinaryColor; assert_eq!(BinaryColor::Off.invert(), BinaryColor::On); assert_eq!(BinaryColor::On.invert(), BinaryColor::Off);
Returns true if this color is On.
Examples
use embedded_graphics::pixelcolor::BinaryColor; assert!(BinaryColor::On.is_on());