Struct embedded_graphics::style::Style
source · pub struct Style<P: PixelColor> {
pub fill_color: Option<P>,
pub stroke_color: Option<P>,
pub stroke_width: u8,
}Expand description
Style properties for an object
Fields
fill_color: Option<P>Fill colour of the object
For fonts, this is the background colour of the text
stroke_color: Option<P>Stroke (border/line) color of the object
For fonts, this is the foreground colour of the text
stroke_width: u8Stroke width
Set the stroke width for an object. Has no effect on fonts.
Implementations
sourceimpl<P> Style<P>where
P: PixelColor,
impl<P> Style<P>where
P: PixelColor,
sourcepub fn with_stroke(stroke_color: P) -> Self
pub fn with_stroke(stroke_color: P) -> Self
Create a new style with a given stroke value and defaults for everything else