Trait embedded_graphics::transform::Transform [−][src]
pub trait Transform {
fn translate(&self, by: Coord) -> Self;
fn translate_mut(&mut self, by: Coord) -> &mut Self;
}Transform operations
Required Methods
fn translate(&self, by: Coord) -> Self
Move the origin of an object by a given number of (x, y) pixels, returning a new object
fn translate_mut(&mut self, by: Coord) -> &mut Self
Move the origin of an object by a given number of (x, y) pixels, mutating the object in place